﻿namespace Cop.Borovkov.Var3.Components
{
    /// <summary>
    /// Визуальный компонент выбора из списка значений
    /// </summary>
    public partial class CustomListBox : UserControl
    {
        private event EventHandler? _selectedChanged;
        private event Action<Exception>? _errorOccured;

        /// <summary>
        /// </summary>
        public CustomListBox()
        {
            InitializeComponent();
        }

        /// <summary>
        /// Событие возникающие при изменении списка
        /// </summary>
        public event EventHandler ValueChanged
        {
            add => _selectedChanged += value;
            remove => _selectedChanged -= value;
        }

        /// <summary>
        /// Обработка ошибок
        /// </summary>
        public event Action<Exception> AnErrorOccurred
        {
            add => _errorOccured += value;
            remove => _errorOccured -= value;
        }

        /// <summary>
        /// Заполнить список значениями
        /// </summary>
        /// <param name="strings">Список значений</param>
        public void FillValues(IEnumerable<string> strings)
        {
            InerlistBox.Items.Clear();
            InerlistBox.Items.AddRange(strings.ToArray());
        }

        /// <summary>
        /// Очистить список
        /// </summary>
        public void Clear() 
        {
            InerlistBox.ClearSelected();
            InerlistBox.DataSource = null;
            InerlistBox.Items.Clear();
            InerlistBox.Refresh();
        }

        private void InerlistBox_SelectedIndexChanged(object sender, EventArgs e)
        {
            try
            {
                _selectedChanged?.Invoke(sender, e);
            }
            catch (Exception ex)
            {
                _errorOccured?.Invoke(ex);
            }
        }

        /// <summary>
        /// Выбранное значение
        /// </summary>
        public string Selected
        {
            get => (string?)InerlistBox.SelectedItem ?? string.Empty;
            set => InerlistBox.SelectedItem = value;
        }
    }
}
